#read the files defining DV locations and names
dv2=c(1,9,17,25,33,41,49,57,2,10,18,26,34,42,50,58);
dv3=c(3,11,19,27,35,43,51,59,4,12,20,28,36,44,52,60);
dv4=c(5,13,21,29,37,45,53,61,6,14,22,30,38,46,54,62);
dv5=c(7,15,23,31,39,47,55,63,8,16,24,32,40,48,56,64);
N.dv<-cbind(dv2,dv3,dv4,dv5)
dimnames(N.dv)=list(NULL,as.character(201:204))
#read in the calibration and function data
dvtag0<-read.table("c:/qcls/rprogs/dvtag.txt",header=T,sep="",as.is=T)# define calcr10 function
dvtag<-as.matrix(dvtag0[,c(1,4:11)])
calcr10<-function(v0,dv) {
v = v0/dvtag[dv,"GAIN"] ; f=dvtag[dv,"f"]
z=v   # default case f in dvtag not in range
#   case 1  #most thermistors: ysi 44032 (-40 to 70 C; +/-0.2 K)
if(f==1){        
        a = c(-167.703870964, 672.381225444, -0.121190356078);
        v0 = 2500; r0 = 30.1e3;     #[mV; ohm]
        rth = r0*v/(v0-v);   #[ohm]
        rth[v > 2500 | v < 0 ]<-NA ;
        z = a[1] + a[2]*rth^a[3];  #[C]
}   
#  case 2  #laser sink temperature: ysi 46016 (-40 to 40 C; +/-0.1 K)
if(f==2){ 
        a = c(-160.989607984, 572.749337491, -0.122098422296);
        ibias = 100e-6; r0 = 50e3;          #[A; ohm]
        rth = 1./(ibias/(v/1000) - 1/r0);  #[ohm]
        rth[rth<0]<-NA
        z = a[1] + a[2]*rth^a[3];          #[C]
}
#   case 3  #temperature controllers
if(f==3){
        a = c(-0.000006503, 0.03805, -17.415);
#       z = polyval(a,v);   #[C]
        z = a[1]*v^2 + a[2]*v + a[3];   #[C]
}
#    case 4  #pressure
if(f==4){
      b=dvtag[dv,c("Z1","Z2","V.Z1.mv","V.Z2.mv")]
      z = b[1] + (b[2]-b[1])/(b[4]-b[3])*(v-b[3]);    #[torr; psi]
}
#   case 5  #chiller flow (to be replaced by calibration data fit)
if(f==5){
      b=dvtag[dv,c("Z1","Z2","V.Z1.mv","V.Z2.mv")]
      z = b[1] + (b[2]-b[1])/(b[4]-b[3])*(v-b[3]);    #[LPM]
}
#   case 6  #0-1000 sccm flowmeter replace by new function
if(f==6){
        a0= 32e3; a1=31644.77; a2=844.99 ; v0=990
        z = (a1*exp((v-v0)/a2) -a0)/(v-v0);   #[sccm]
}
#   case 7  #0-6 slpm flowmeter replace by new function
if(f==7){
        a0= 187; a1= 185.34; a2=833.94 ; v0=990
        z = (a1*exp((v-v0)/a2) -a0)/(v-v0);    #[SLPM]
}
#   case 8  #28 VDC current monitor
if(f==8){
      b=dvtag[dv,c("Z1","Z2","V.Z1.mv","V.Z2.mv")]
        z = b[1] + (b[2]-b[1])/(b[4]-b[3])*(v-b[3]);    #[A]
}
#   case 9  #pump speed (assume 10 V = 2000 rpm)
if(f==9){
      b=dvtag[dv,c("Z1","Z2","V.Z1.mv","V.Z2.mv")]
        z = b[1] + (b[2]-b[1])/(b[4]-b[3])*(v-b[3]);    #[rpm]
}
return(as.vector(z))
} ##

# start processing data
nn<-scan("infile",n=3,what=character(),skip=1) ; flt<-scan("flt",what=character())
print(nn)
#must be run using R CMD from the c:\qcls\data\flt folder
for(id in 201:204){
readfile<-paste("c:/QCLS/DATA/",flt,"/CR10/D",nn[1],".",id,sep="")
writefile<-paste("c:/QCLS/DATA/",flt,"/CR10/O",nn[1],".",id,sep="")
print(c(id,readfile,writefile))
D.id<-as.matrix(read.table(readfile,skip=1,header=F))
if(id==201)D.id<-D.id[,c(1:5,9:ncol(D.id))]
#if(id == 201)dimnames(D.id)<-list(NULL,c("GMTs","day","hr","min","s","day0","hhmm","ss",as.character(N.dv[,as.character(id)])))
dimnames(D.id)<-list(NULL,c("GMTs","day","hr","min","s",as.character(N.dv[,as.character(id)])))
O.id<-D.id[,1:5]
for(j in 1:16){    # calibrate the channels and write the final to the O file
dv<-N.dv[,as.character(id)][j]
dum<-calcr10(v0=D.id[,5+j],dv=dv)
O.id<-cbind(O.id,dum)
#quickplot
qdv<-as.character(dv);if(dv<10)qdv<-paste("0",dv,sep="")
png(file=paste("c:/QCLS/DATA/",flt,"/analysis/O",flt,"_",dv,".png",sep=""))
yl<-dvtag[dv,c("RANGE1","RANGE2")];if(sum(!is.finite(yl))>0)yl<-range(dum,na.rm=T)
plot(O.id[,1],dum,ylim=yl,type="l",ylab=dvtag0[dv,3],main=paste("dv=",dv,dvtag0[dv,2]));dev.off()
}
dimnames(O.id)<-dimnames(D.id)
write.table(O.id,file=writefile,quote=F,sep="\t",row.names=F)
}
graphics.off()
#make the postscript file
postscript(file=paste("c:/QCLS/DATA/",flt,"/analysis/Fig.",flt,".ps",sep=""),horizontal=F)
par(mfrow=c(2,2),mar=c(4,4,2,.5))
for(id in 201:204){
readfile<-paste("c:/QCLS/DATA/",flt,"/CR10/O",nn[1],".",id,sep="")
O.id<-as.matrix(read.table(readfile,header=T))
for(j in 1:16){    # calibrate the channels and write the final to the O file
dv<-N.dv[,as.character(id)][j]
yl<-dvtag[dv,c("RANGE1","RANGE2")];if(sum(!is.finite(yl))>0)yl<-range(dum,na.rm=T)
plot(O.id[,1],O.id[,j+5],ylim=yl,type="l",ylab=dvtag0[dv,3],main=paste("dv=",dv,dvtag0[dv,2]))
}
}
dev.off()
system(paste("cmd /c ps2pdf c:/QCLS/DATA/",flt,"/analysis/Fig.",flt,".ps",sep=""))
#plot the the str and stc files
system("cmd /c dir /b CO2\\*.str > co2_str.txt"); co2.str.file<-scan("co2_str.txt",what=character())
system("cmd /c dir /b DUAL\\*.str > dual_str.txt"); dual.str.file<-scan("dual_str.txt",what=character())
cc.str<-as.matrix(read.table(paste("c:/QCLS/DATA/",flt,"/CO2/",co2.str.file,sep=""),skip=1,header=F))
cc.str[,1]=cc.str[,1]-3281990400.
day<-cc.str[,1]/86400+1 
cc<-cbind(cc.str,day); dimnames(cc)<-list(NULL,c("GMTs","CO2.str","GMT_day"))
cc[abs(cc[,2])>3e6,2]<-NA ; if(sum(is.na(cc[,2]))>0){print("Invalid CO2-str");print(which(is.na(cc[,2])))}
dd.str<-as.matrix(read.table(paste("c:/QCLS/DATA/",flt,"/DUAL/",dual.str.file,sep=""),skip=1,header=F))
dd.str[,1]=dd.str[,1]-3281990400.
dday<-dd.str[,1]/86400+1 
dd<-cbind(dd.str,dday)
dimnames(dd)<-list(NULL,c("GMTs","CH4","N2O","CO","GMT_day") )
dd[abs(dd[,2])>3e4,2]<-NA ;dd[abs(dd[,3])>3e4,3]<-NA ;dd[abs(dd[,4])>3e4,4]<-NA ;
png(paste("c:\\QCLS\\DATA\\",flt,"\\analysis\\str_raw",flt,".png",sep=""))
  par(mar=c(4,4,4,1)+.15,mfrow=c(2,2))
  plot(cc[,c(3,2)],type="l",xlab="GMT day",ylab="CO2 raw",main=paste(flt,"CO2_Raw"))
  plot(dd[,c(5,2)],type="l",xlab="GMT day",ylab="CH4 raw",main=paste(flt,"CH4_Raw"))
  plot(dd[,c(5,3)],type="l",xlab="GMT day",ylab="N2O raw",main=paste(flt,"N2O_Raw"))
  plot(dd[,c(5,4)],type="l",xlab="GMT day",ylab="CO raw",main=paste(flt,"CO_Raw"))
dev.off()
postscript(paste("c:\\QCLS\\DATA\\",flt,"\\analysis\\str_raw",flt,".ps",sep=""))
  par(mar=c(4,4,4,1)+.15,mfrow=c(2,2))
  plot(cc[,c(3,2)],type="l",xlab="GMT day",ylab="CO2 raw",main=paste(flt,"CO2_Raw"))
  plot(dd[,c(5,2)],type="l",xlab="GMT day",ylab="CH4 raw",main=paste(flt,"CH4_Raw"))
  plot(dd[,c(5,3)],type="l",xlab="GMT day",ylab="N2O raw",main=paste(flt,"N2O_Raw"))
  plot(dd[,c(5,4)],type="l",xlab="GMT day",ylab="CO raw",main=paste(flt,"CO_Raw"))
dev.off()
system(paste("cmd /c ps2pdf c:/QCLS/DATA/",flt,"/analysis/str_raw",flt,".ps",sep=""))
# stc file simple plots
system("cmd /c dir /b CO2\\*.stc > co2_stc.txt"); co2.stc.file<-scan("co2_stc.txt",what=character())
system("cmd /c dir /b DUAL\\*.stc > dual_stc.txt"); dual.stc.file<-scan("dual_stc.txt",what=character())
path2stc<-paste("CO2\\",scan("co2_stc.txt",what=character()),sep="")
path2stcd<-paste("DUAL\\",scan("dual_stc.txt",what=character()),sep="")
dkeepers<-c("time","Range_F.1_L.1","Range_F.1_L.2","Range_F.2_L.1","Range_F.2_L.2","X1","pos1","X2","pos2")
ckeepers<-c("time","Range_F.1_L.1","Range_F.2_L.1","X1","pos1")
cc.stc<-as.matrix(read.table(path2stc,skip=1,header=T,sep=",",as.is=T)[,ckeepers] )
cc.stc[,1]=cc.stc[,1]-3281990400.
day<-cc.stc[,1]/86400+1 
cc<-cbind(cc.stc,day); dimnames(cc)<-list(NULL,c(dimnames(cc.stc)[[2]],"GMT_day"))
dd.stc<-as.matrix(read.table(path2stcd,skip=1,header=T,sep=",",as.is=T)[,dkeepers] )
dd.stc[,1]=dd.stc[,1]-3281990400.  #Jan 1 2008 igor time seconds
dday<-dd.stc[,1]/86400+1 
dd<-cbind(dd.stc,dday);dimnames(dd)<-list(NULL,c(dimnames(dd.stc)[[2]],"GMT_day") )
#======================o======================================================
png(paste("c:\\QCLS\\DATA\\",flt,"\\analysis\\","CO2_stc",flt,".png",sep=""),height=1000,width=800)
par(mar=c(4,4,4,1)+.15,mfrow=c(2,2))
for(nn in ckeepers[2:5]){    plot(cc[,"GMT_day"],cc[,nn],xlab="GMTs",ylab=nn,type="l")
title(line=2.5,main=paste(flt,"CO2",nn,"str")) }
dev.off()
#======================o======================================================
png(paste("c:\\QCLS\\DATA\\",flt,"\\analysis\\","DUAL_stc",flt,"_1.png",sep=""),height=1000,width=800)
par(mar=c(4,4,4,1)+.15,mfrow=c(2,2))
for(nn in dkeepers[2:5]){    plot(dd[,"GMT_day"],dd[,nn],type="l",xlab="GMTs",ylab=nn)
title(line=2.5,main=paste("DUAL",nn,"str")) 
mtext(line=-1,cex=.75,flt)}
dev.off()
png(paste("c:\\QCLS\\DATA\\",flt,"\\analysis\\","DUAL_stc",flt,"_2.png",sep=""),height=1000,width=800)
par(mar=c(4,4,4,1)+.15,mfrow=c(2,2))
for(nn in dkeepers[6:9]){    plot(dd[,"GMT_day"],dd[,nn],type="l",xlab="GMTs",ylab=nn)
title(line=2.5,main=paste(nn,"str")) }
mtext(line=-1,cex=.75,flt)
dev.off()
#======================o======================================================
postscript(paste("c:\\QCLS\\DATA\\",flt,"\\analysis\\","stc",flt,".ps",sep=""),horizontal=F)
par(mar=c(4,4,4,1)+.15,mfrow=c(2,2))
for(nn in ckeepers[2:5]){    plot(cc[,"GMT_day"],cc[,nn],xlab="GMTs",ylab=nn,type="l")
title(line=2.5,main=paste(flt,"CO2",nn,"str")) }
dev.off()
#======================o======================================================
for(nn in dkeepers[2:5]){    plot(dd[,"GMT_day"],dd[,nn],type="l",xlab="GMTs",ylab=nn)
title(line=2.5,main=paste(nn,"str")) }
mtext(line=-1,cex=.75,flt)
for(nn in dkeepers[6:9]){    plot(dd[,"GMT_day"],dd[,nn],type="l",xlab="GMTs",ylab=nn)
title(line=2.5,main=paste(nn,"str")) }
mtext(line=-1,cex=.75,flt)
dev.off()
system(paste("cmd /c ps2pdf c:/QCLS/DATA/",flt,"/analysis/stc",flt,".ps",sep=""))
